@@ -10,6 +10,7 @@ use OCP\IUserSession;
 
 use OCA\Notes\Service\NotesService;
 use OCA\Notes\Service\MetaService;
+use OCA\Notes\Service\InsufficientStorageException;
 use OCA\Notes\Db\Note;
 
 /**
@@ -113,12 +114,9 @@ class NotesApiController extends ApiController {
 	 */
 	public function get($id, $exclude = '') {
 		$exclude = explode(',', $exclude);
-
-		return $this->respond(function () use ($id, $exclude) {
-			$note = $this->service->get($id, $this->getUID());
-			$note = $this->excludeFields($note, $exclude);
-			return $note;
-		});
+		$note = $this->service->get($id, $this->getUID());
+		$note = $this->excludeFields($note, $exclude);
+		return new DataResponse($note);
 	}
 
 
@@ -134,10 +132,19 @@ class NotesApiController extends ApiController {
 	 * @return DataResponse
 	 */
 	public function create($content, $category = null, $modified = 0, $favorite = null) {
-		return $this->respond(function () use ($content, $category, $modified, $favorite) {
+		try {
 			$note = $this->service->create($this->getUID());
-			return $this->updateData($note->getId(), $content, $category, $modified, $favorite);
-		});
+			try {
+				$note = $this->updateData($note->getId(), $content, $category, $modified, $favorite);
+			} catch (\Throwable $e) {
+				// roll-back note creation
+				$this->service->delete($note->getId(), $this->getUID());
+				throw $e;
+			}
+			return new DataResponse($note);
+		} catch (InsufficientStorageException $e) {
+			return new DataResponse([], Http::STATUS_INSUFFICIENT_STORAGE);
+		}
 	}
 
 
@@ -154,9 +161,12 @@ class NotesApiController extends ApiController {
 	 * @return DataResponse
 	 */
 	public function update($id, $content = null, $category = null, $modified = 0, $favorite = null) {
-		return $this->respond(function () use ($id, $content, $category, $modified, $favorite) {
-			return $this->updateData($id, $content, $category, $modified, $favorite);
-		});
+		try {
+			$note = $this->updateData($id, $content, $category, $modified, $favorite);
+			return new DataResponse($note);
+		} catch (InsufficientStorageException $e) {
+			return new DataResponse([], Http::STATUS_INSUFFICIENT_STORAGE);
+		}
 	}
 
 	/**
@@ -187,9 +197,7 @@ class NotesApiController extends ApiController {
 	 * @return DataResponse
 	 */
 	public function destroy($id) {
-		return $this->respond(function () use ($id) {
-			$this->service->delete($id, $this->getUID());
-			return [];
-		});
+		$this->service->delete($id, $this->getUID());
+		return new DataResponse([]);
 	}
 }
