@@ -126,6 +126,9 @@ class NotesService {
 	public function create($userId) : Note {
 		$title = $this->l10n->t('New note');
 		$folder = $this->getFolderForUser($userId);
+		if ($folder->getFreeSpace() <= 1) {
+			throw new InsufficientStorageException();
+		}
 
 		// check new note exists already and we need to number it
 		// pass -1 because no file has id -1 and that will ensure
@@ -133,10 +136,17 @@ class NotesService {
 		$path = $this->noteUtil->generateFileName($folder, $title, $this->settings->get($userId, 'fileSuffix'), -1);
 		$file = $folder->newFile($path);
 
-		// If server-side encryption is activated, the server creates an empty file without signature
-		// which leads to an GenericEncryptionException('Missing Signature') afterwards.
-		// Saving a space-char (and removing it later) is a working work-around.
-		$file->putContent(' ');
+		// try to write some content
+		try {
+			// If server-side encryption is activated, the server creates an empty file without signature
+			// which leads to an GenericEncryptionException('Missing Signature') afterwards.
+			// Saving a space-char (and removing it later) is a working work-around.
+			$file->putContent(' ');
+		} catch (\Throwable $e) {
+			// if writing the content fails, we have to roll back the note creation
+			$this->delete($file->getId(), $userId);
+			throw $e;
+		}
 
 		return $this->getNote($file, $folder);
 	}
@@ -173,6 +183,9 @@ class NotesService {
 		}
 
 		if ($content !== null) {
+			if ($file->getParent()->getFreeSpace() < strlen($content)) {
+				throw new InsufficientStorageException();
+			}
 			$file->putContent($content);
 		}
 
@@ -234,15 +247,6 @@ class NotesService {
 		return $file[0];
 	}
 
-	/**
-	 * @param string $userId the user id
-	 * @return boolean true if folder is accessible, or Exception otherwise
-	 */
-	public function checkNotesFolder($userId) {
-		$this->getFolderForUser($userId);
-		return true;
-	}
-
 	/**
 	 * @param string $userId the user id
 	 * @return Folder
